# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/catalog/v1/catalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/catalog/v1/catalog.proto',
  package='github.com.metaprov.modelaapi.services.catalog.v1',
  syntax='proto3',
  serialized_options=b'Z1github.com/metaprov/modelaapi/services/catalog/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n?github.com/metaprov/modelaapi/services/catalog/v1/catalog.proto\x12\x31github.com.metaprov.modelaapi.services.catalog.v1\x1a\x1cgoogle/api/annotations.proto\x1aGgithub.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1/generated.proto\"\xbf\x01\n\x15ListAlgorithmsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x02 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x16ListAlgorithmsResponse\x12U\n\x05items\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.AlgorithmList\"6\n\x13GetAlgorithmRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"h\n\x14GetAlgorithmResponse\x12P\n\x04item\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Algorithm\"\xc3\x01\n\x17ListMLFrameworksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x66\n\x06labels\x18\x02 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"s\n\x18ListMLFrameworksResponse\x12W\n\x05items\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MLFrameworkList\"8\n\x15GetMLFrameworkRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"l\n\x16GetMLFrameworkResponse\x12R\n\x04item\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MLFramework\"\xb7\x01\n\x11ListCloudsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12`\n\x06labels\x18\x02 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\x12ListCloudsResponse\x12Q\n\x05items\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CloudList\"2\n\x0fGetCloudRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"`\n\x10GetCloudResponse\x12L\n\x04item\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Cloud\"\xc7\x01\n\x19ListPublicDatasetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"w\n\x1aListPublicDatasetsResponse\x12Y\n\x05items\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PublicDatasetList\":\n\x17GetPublicDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"p\n\x18GetPublicDatasetResponse\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PublicDataset\"?\n\x1c\x44ownloadPublicDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\",\n\x1d\x44ownloadPublicDatasetResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\">\n\x1bPreviewPublicDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"+\n\x1cPreviewPublicDatasetResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\"N\n\x1b\x41pplyPublicDatasetCRRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x63rname\x18\x03 \x01(\t\"+\n\x1c\x41pplyPublicDatasetCRResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\"\xcb\x01\n\x1bListPretrainedModelsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12j\n\x06labels\x18\x02 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x1cListPretrainedModelsResponse\x12[\n\x05items\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PretrainedModelList\"<\n\x19GetPretrainedModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"t\n\x1aGetPretrainedModelResponse\x12V\n\x04item\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PretrainedModel\"\xc9\x01\n\x1aListWorkloadClassesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12i\n\x06labels\x18\x02 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"x\n\x1bListWorkloadClassesResponse\x12Y\n\x05items\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkloadClassList\":\n\x17GetWorkloadClassRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"p\n\x18GetWorkloadClassResponse\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkloadClass\"\xc9\x01\n\x1aListUserRoleClassesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12i\n\x06labels\x18\x02 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"x\n\x1bListUserRoleClassesResponse\x12Y\n\x05items\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.UserRoleClassList\":\n\x17GetUserRoleClassRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"p\n\x18GetUserRoleClassResponse\x12T\n\x04item\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.UserRoleClass2\x9e\x18\n\x0e\x43\x61talogService\x12\xbb\x01\n\rListAlgorithm\x12H.github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest\x1aI.github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\x12\rv1/algorithms\x12\xbe\x01\n\x0cGetAlgorithm\x12\x46.github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmRequest\x1aG.github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/algorithms/{name}\x12\xc5\x01\n\x10ListMLFrameworks\x12J.github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest\x1aK.github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/mlframeworks\x12\xc6\x01\n\x0eGetMLFramework\x12H.github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkRequest\x1aI.github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/mlframeworks/{name}\x12\xad\x01\n\nListClouds\x12\x44.github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest\x1a\x45.github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsResponse\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/v1/clouds\x12\xae\x01\n\x08GetCloud\x12\x42.github.com.metaprov.modelaapi.services.catalog.v1.GetCloudRequest\x1a\x43.github.com.metaprov.modelaapi.services.catalog.v1.GetCloudResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/clouds/{name}\x12\xd1\x01\n\x13ListWorkloadClasses\x12M.github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest\x1aN.github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/workloadclasses\x12\xcf\x01\n\x10GetWorkloadClass\x12J.github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassRequest\x1aK.github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/workloadclasses/{name}\x12\xd1\x01\n\x13ListUserRoleClasses\x12M.github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesRequest\x1aN.github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/userroleclasses\x12\xcf\x01\n\x10GetUserRoleClass\x12J.github.com.metaprov.modelaapi.services.catalog.v1.GetUserRoleClassRequest\x1aK.github.com.metaprov.modelaapi.services.catalog.v1.GetUserRoleClassResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/userroleclasses/{name}\x12\xcc\x01\n\x11ListPublicDataset\x12L.github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest\x1aM.github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/publicdatasets\x12\xce\x01\n\x10GetPublicDataset\x12J.github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetRequest\x1aK.github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/publicdatasets/{name}\x12\xe6\x01\n\x15\x44ownloadPublicDataset\x12O.github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetRequest\x1aP.github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/publicdatasets/{name}:download\x12\xe2\x01\n\x14PreviewPublicDataset\x12N.github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetRequest\x1aO.github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/publicdatasets/{name}:preview\x12\xe0\x01\n\x14\x41pplyPublicDatasetCR\x12N.github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRRequest\x1aO.github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/publicdatasets/{name}:applyB3Z1github.com/metaprov/modelaapi/services/catalog/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTALGORITHMSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=413,
)

_LISTALGORITHMSREQUEST = _descriptor.Descriptor(
  name='ListAlgorithmsRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTALGORITHMSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=413,
)


_LISTALGORITHMSRESPONSE = _descriptor.Descriptor(
  name='ListAlgorithmsResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=526,
)


_GETALGORITHMREQUEST = _descriptor.Descriptor(
  name='GetAlgorithmRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=582,
)


_GETALGORITHMRESPONSE = _descriptor.Descriptor(
  name='GetAlgorithmResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=584,
  serialized_end=688,
)


_LISTMLFRAMEWORKSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=413,
)

_LISTMLFRAMEWORKSREQUEST = _descriptor.Descriptor(
  name='ListMLFrameworksRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTMLFRAMEWORKSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=886,
)


_LISTMLFRAMEWORKSRESPONSE = _descriptor.Descriptor(
  name='ListMLFrameworksResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=888,
  serialized_end=1003,
)


_GETMLFRAMEWORKREQUEST = _descriptor.Descriptor(
  name='GetMLFrameworkRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1005,
  serialized_end=1061,
)


_GETMLFRAMEWORKRESPONSE = _descriptor.Descriptor(
  name='GetMLFrameworkResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1063,
  serialized_end=1171,
)


_LISTCLOUDSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=413,
)

_LISTCLOUDSREQUEST = _descriptor.Descriptor(
  name='ListCloudsRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTCLOUDSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1174,
  serialized_end=1357,
)


_LISTCLOUDSRESPONSE = _descriptor.Descriptor(
  name='ListCloudsResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1359,
  serialized_end=1462,
)


_GETCLOUDREQUEST = _descriptor.Descriptor(
  name='GetCloudRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetCloudRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetCloudRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetCloudRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1464,
  serialized_end=1514,
)


_GETCLOUDRESPONSE = _descriptor.Descriptor(
  name='GetCloudResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetCloudResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetCloudResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1516,
  serialized_end=1612,
)


_LISTPUBLICDATASETSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=413,
)

_LISTPUBLICDATASETSREQUEST = _descriptor.Descriptor(
  name='ListPublicDatasetsRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPUBLICDATASETSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1615,
  serialized_end=1814,
)


_LISTPUBLICDATASETSRESPONSE = _descriptor.Descriptor(
  name='ListPublicDatasetsResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1816,
  serialized_end=1935,
)


_GETPUBLICDATASETREQUEST = _descriptor.Descriptor(
  name='GetPublicDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1937,
  serialized_end=1995,
)


_GETPUBLICDATASETRESPONSE = _descriptor.Descriptor(
  name='GetPublicDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1997,
  serialized_end=2109,
)


_DOWNLOADPUBLICDATASETREQUEST = _descriptor.Descriptor(
  name='DownloadPublicDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2111,
  serialized_end=2174,
)


_DOWNLOADPUBLICDATASETRESPONSE = _descriptor.Descriptor(
  name='DownloadPublicDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetResponse.raw', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2176,
  serialized_end=2220,
)


_PREVIEWPUBLICDATASETREQUEST = _descriptor.Descriptor(
  name='PreviewPublicDatasetRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2222,
  serialized_end=2284,
)


_PREVIEWPUBLICDATASETRESPONSE = _descriptor.Descriptor(
  name='PreviewPublicDatasetResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetResponse.raw', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2286,
  serialized_end=2329,
)


_APPLYPUBLICDATASETCRREQUEST = _descriptor.Descriptor(
  name='ApplyPublicDatasetCRRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crname', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRRequest.crname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2331,
  serialized_end=2409,
)


_APPLYPUBLICDATASETCRRESPONSE = _descriptor.Descriptor(
  name='ApplyPublicDatasetCRResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRResponse.raw', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2411,
  serialized_end=2454,
)


_LISTPRETRAINEDMODELSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=413,
)

_LISTPRETRAINEDMODELSREQUEST = _descriptor.Descriptor(
  name='ListPretrainedModelsRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTPRETRAINEDMODELSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2457,
  serialized_end=2660,
)


_LISTPRETRAINEDMODELSRESPONSE = _descriptor.Descriptor(
  name='ListPretrainedModelsResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2662,
  serialized_end=2785,
)


_GETPRETRAINEDMODELREQUEST = _descriptor.Descriptor(
  name='GetPretrainedModelRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetPretrainedModelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetPretrainedModelRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetPretrainedModelRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2787,
  serialized_end=2847,
)


_GETPRETRAINEDMODELRESPONSE = _descriptor.Descriptor(
  name='GetPretrainedModelResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetPretrainedModelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetPretrainedModelResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2849,
  serialized_end=2965,
)


_LISTWORKLOADCLASSESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=413,
)

_LISTWORKLOADCLASSESREQUEST = _descriptor.Descriptor(
  name='ListWorkloadClassesRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTWORKLOADCLASSESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2968,
  serialized_end=3169,
)


_LISTWORKLOADCLASSESRESPONSE = _descriptor.Descriptor(
  name='ListWorkloadClassesResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3171,
  serialized_end=3291,
)


_GETWORKLOADCLASSREQUEST = _descriptor.Descriptor(
  name='GetWorkloadClassRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassRequest.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3293,
  serialized_end=3351,
)


_GETWORKLOADCLASSRESPONSE = _descriptor.Descriptor(
  name='GetWorkloadClassResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3353,
  serialized_end=3465,
)


_LISTUSERROLECLASSESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=368,
  serialized_end=413,
)

_LISTUSERROLECLASSESREQUEST = _descriptor.Descriptor(
  name='ListUserRoleClassesRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesRequest.labels', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTUSERROLECLASSESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3468,
  serialized_end=3669,
)


_LISTUSERROLECLASSESRESPONSE = _descriptor.Descriptor(
  name='ListUserRoleClassesResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3671,
  serialized_end=3791,
)


_GETUSERROLECLASSREQUEST = _descriptor.Descriptor(
  name='GetUserRoleClassRequest',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetUserRoleClassRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetUserRoleClassRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetUserRoleClassRequest.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3793,
  serialized_end=3851,
)


_GETUSERROLECLASSRESPONSE = _descriptor.Descriptor(
  name='GetUserRoleClassResponse',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetUserRoleClassResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.catalog.v1.GetUserRoleClassResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3853,
  serialized_end=3965,
)

_LISTALGORITHMSREQUEST_LABELSENTRY.containing_type = _LISTALGORITHMSREQUEST
_LISTALGORITHMSREQUEST.fields_by_name['labels'].message_type = _LISTALGORITHMSREQUEST_LABELSENTRY
_LISTALGORITHMSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._ALGORITHMLIST
_GETALGORITHMRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._ALGORITHM
_LISTMLFRAMEWORKSREQUEST_LABELSENTRY.containing_type = _LISTMLFRAMEWORKSREQUEST
_LISTMLFRAMEWORKSREQUEST.fields_by_name['labels'].message_type = _LISTMLFRAMEWORKSREQUEST_LABELSENTRY
_LISTMLFRAMEWORKSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._MLFRAMEWORKLIST
_GETMLFRAMEWORKRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._MLFRAMEWORK
_LISTCLOUDSREQUEST_LABELSENTRY.containing_type = _LISTCLOUDSREQUEST
_LISTCLOUDSREQUEST.fields_by_name['labels'].message_type = _LISTCLOUDSREQUEST_LABELSENTRY
_LISTCLOUDSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._CLOUDLIST
_GETCLOUDRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._CLOUD
_LISTPUBLICDATASETSREQUEST_LABELSENTRY.containing_type = _LISTPUBLICDATASETSREQUEST
_LISTPUBLICDATASETSREQUEST.fields_by_name['labels'].message_type = _LISTPUBLICDATASETSREQUEST_LABELSENTRY
_LISTPUBLICDATASETSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._PUBLICDATASETLIST
_GETPUBLICDATASETRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._PUBLICDATASET
_LISTPRETRAINEDMODELSREQUEST_LABELSENTRY.containing_type = _LISTPRETRAINEDMODELSREQUEST
_LISTPRETRAINEDMODELSREQUEST.fields_by_name['labels'].message_type = _LISTPRETRAINEDMODELSREQUEST_LABELSENTRY
_LISTPRETRAINEDMODELSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._PRETRAINEDMODELLIST
_GETPRETRAINEDMODELRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._PRETRAINEDMODEL
_LISTWORKLOADCLASSESREQUEST_LABELSENTRY.containing_type = _LISTWORKLOADCLASSESREQUEST
_LISTWORKLOADCLASSESREQUEST.fields_by_name['labels'].message_type = _LISTWORKLOADCLASSESREQUEST_LABELSENTRY
_LISTWORKLOADCLASSESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._WORKLOADCLASSLIST
_GETWORKLOADCLASSRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._WORKLOADCLASS
_LISTUSERROLECLASSESREQUEST_LABELSENTRY.containing_type = _LISTUSERROLECLASSESREQUEST
_LISTUSERROLECLASSESREQUEST.fields_by_name['labels'].message_type = _LISTUSERROLECLASSESREQUEST_LABELSENTRY
_LISTUSERROLECLASSESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._USERROLECLASSLIST
_GETUSERROLECLASSRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2._USERROLECLASS
DESCRIPTOR.message_types_by_name['ListAlgorithmsRequest'] = _LISTALGORITHMSREQUEST
DESCRIPTOR.message_types_by_name['ListAlgorithmsResponse'] = _LISTALGORITHMSRESPONSE
DESCRIPTOR.message_types_by_name['GetAlgorithmRequest'] = _GETALGORITHMREQUEST
DESCRIPTOR.message_types_by_name['GetAlgorithmResponse'] = _GETALGORITHMRESPONSE
DESCRIPTOR.message_types_by_name['ListMLFrameworksRequest'] = _LISTMLFRAMEWORKSREQUEST
DESCRIPTOR.message_types_by_name['ListMLFrameworksResponse'] = _LISTMLFRAMEWORKSRESPONSE
DESCRIPTOR.message_types_by_name['GetMLFrameworkRequest'] = _GETMLFRAMEWORKREQUEST
DESCRIPTOR.message_types_by_name['GetMLFrameworkResponse'] = _GETMLFRAMEWORKRESPONSE
DESCRIPTOR.message_types_by_name['ListCloudsRequest'] = _LISTCLOUDSREQUEST
DESCRIPTOR.message_types_by_name['ListCloudsResponse'] = _LISTCLOUDSRESPONSE
DESCRIPTOR.message_types_by_name['GetCloudRequest'] = _GETCLOUDREQUEST
DESCRIPTOR.message_types_by_name['GetCloudResponse'] = _GETCLOUDRESPONSE
DESCRIPTOR.message_types_by_name['ListPublicDatasetsRequest'] = _LISTPUBLICDATASETSREQUEST
DESCRIPTOR.message_types_by_name['ListPublicDatasetsResponse'] = _LISTPUBLICDATASETSRESPONSE
DESCRIPTOR.message_types_by_name['GetPublicDatasetRequest'] = _GETPUBLICDATASETREQUEST
DESCRIPTOR.message_types_by_name['GetPublicDatasetResponse'] = _GETPUBLICDATASETRESPONSE
DESCRIPTOR.message_types_by_name['DownloadPublicDatasetRequest'] = _DOWNLOADPUBLICDATASETREQUEST
DESCRIPTOR.message_types_by_name['DownloadPublicDatasetResponse'] = _DOWNLOADPUBLICDATASETRESPONSE
DESCRIPTOR.message_types_by_name['PreviewPublicDatasetRequest'] = _PREVIEWPUBLICDATASETREQUEST
DESCRIPTOR.message_types_by_name['PreviewPublicDatasetResponse'] = _PREVIEWPUBLICDATASETRESPONSE
DESCRIPTOR.message_types_by_name['ApplyPublicDatasetCRRequest'] = _APPLYPUBLICDATASETCRREQUEST
DESCRIPTOR.message_types_by_name['ApplyPublicDatasetCRResponse'] = _APPLYPUBLICDATASETCRRESPONSE
DESCRIPTOR.message_types_by_name['ListPretrainedModelsRequest'] = _LISTPRETRAINEDMODELSREQUEST
DESCRIPTOR.message_types_by_name['ListPretrainedModelsResponse'] = _LISTPRETRAINEDMODELSRESPONSE
DESCRIPTOR.message_types_by_name['GetPretrainedModelRequest'] = _GETPRETRAINEDMODELREQUEST
DESCRIPTOR.message_types_by_name['GetPretrainedModelResponse'] = _GETPRETRAINEDMODELRESPONSE
DESCRIPTOR.message_types_by_name['ListWorkloadClassesRequest'] = _LISTWORKLOADCLASSESREQUEST
DESCRIPTOR.message_types_by_name['ListWorkloadClassesResponse'] = _LISTWORKLOADCLASSESRESPONSE
DESCRIPTOR.message_types_by_name['GetWorkloadClassRequest'] = _GETWORKLOADCLASSREQUEST
DESCRIPTOR.message_types_by_name['GetWorkloadClassResponse'] = _GETWORKLOADCLASSRESPONSE
DESCRIPTOR.message_types_by_name['ListUserRoleClassesRequest'] = _LISTUSERROLECLASSESREQUEST
DESCRIPTOR.message_types_by_name['ListUserRoleClassesResponse'] = _LISTUSERROLECLASSESRESPONSE
DESCRIPTOR.message_types_by_name['GetUserRoleClassRequest'] = _GETUSERROLECLASSREQUEST
DESCRIPTOR.message_types_by_name['GetUserRoleClassResponse'] = _GETUSERROLECLASSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListAlgorithmsRequest = _reflection.GeneratedProtocolMessageType('ListAlgorithmsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTALGORITHMSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTALGORITHMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest)
  })
_sym_db.RegisterMessage(ListAlgorithmsRequest)
_sym_db.RegisterMessage(ListAlgorithmsRequest.LabelsEntry)

ListAlgorithmsResponse = _reflection.GeneratedProtocolMessageType('ListAlgorithmsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALGORITHMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsResponse)
  })
_sym_db.RegisterMessage(ListAlgorithmsResponse)

GetAlgorithmRequest = _reflection.GeneratedProtocolMessageType('GetAlgorithmRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALGORITHMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmRequest)
  })
_sym_db.RegisterMessage(GetAlgorithmRequest)

GetAlgorithmResponse = _reflection.GeneratedProtocolMessageType('GetAlgorithmResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALGORITHMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmResponse)
  })
_sym_db.RegisterMessage(GetAlgorithmResponse)

ListMLFrameworksRequest = _reflection.GeneratedProtocolMessageType('ListMLFrameworksRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMLFRAMEWORKSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMLFRAMEWORKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest)
  })
_sym_db.RegisterMessage(ListMLFrameworksRequest)
_sym_db.RegisterMessage(ListMLFrameworksRequest.LabelsEntry)

ListMLFrameworksResponse = _reflection.GeneratedProtocolMessageType('ListMLFrameworksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMLFRAMEWORKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksResponse)
  })
_sym_db.RegisterMessage(ListMLFrameworksResponse)

GetMLFrameworkRequest = _reflection.GeneratedProtocolMessageType('GetMLFrameworkRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMLFRAMEWORKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkRequest)
  })
_sym_db.RegisterMessage(GetMLFrameworkRequest)

GetMLFrameworkResponse = _reflection.GeneratedProtocolMessageType('GetMLFrameworkResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMLFRAMEWORKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkResponse)
  })
_sym_db.RegisterMessage(GetMLFrameworkResponse)

ListCloudsRequest = _reflection.GeneratedProtocolMessageType('ListCloudsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCLOUDSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCLOUDSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest)
  })
_sym_db.RegisterMessage(ListCloudsRequest)
_sym_db.RegisterMessage(ListCloudsRequest.LabelsEntry)

ListCloudsResponse = _reflection.GeneratedProtocolMessageType('ListCloudsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLOUDSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsResponse)
  })
_sym_db.RegisterMessage(ListCloudsResponse)

GetCloudRequest = _reflection.GeneratedProtocolMessageType('GetCloudRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetCloudRequest)
  })
_sym_db.RegisterMessage(GetCloudRequest)

GetCloudResponse = _reflection.GeneratedProtocolMessageType('GetCloudResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetCloudResponse)
  })
_sym_db.RegisterMessage(GetCloudResponse)

ListPublicDatasetsRequest = _reflection.GeneratedProtocolMessageType('ListPublicDatasetsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPUBLICDATASETSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPUBLICDATASETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest)
  })
_sym_db.RegisterMessage(ListPublicDatasetsRequest)
_sym_db.RegisterMessage(ListPublicDatasetsRequest.LabelsEntry)

ListPublicDatasetsResponse = _reflection.GeneratedProtocolMessageType('ListPublicDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPUBLICDATASETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsResponse)
  })
_sym_db.RegisterMessage(ListPublicDatasetsResponse)

GetPublicDatasetRequest = _reflection.GeneratedProtocolMessageType('GetPublicDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetRequest)
  })
_sym_db.RegisterMessage(GetPublicDatasetRequest)

GetPublicDatasetResponse = _reflection.GeneratedProtocolMessageType('GetPublicDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetResponse)
  })
_sym_db.RegisterMessage(GetPublicDatasetResponse)

DownloadPublicDatasetRequest = _reflection.GeneratedProtocolMessageType('DownloadPublicDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADPUBLICDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetRequest)
  })
_sym_db.RegisterMessage(DownloadPublicDatasetRequest)

DownloadPublicDatasetResponse = _reflection.GeneratedProtocolMessageType('DownloadPublicDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADPUBLICDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetResponse)
  })
_sym_db.RegisterMessage(DownloadPublicDatasetResponse)

PreviewPublicDatasetRequest = _reflection.GeneratedProtocolMessageType('PreviewPublicDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREVIEWPUBLICDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetRequest)
  })
_sym_db.RegisterMessage(PreviewPublicDatasetRequest)

PreviewPublicDatasetResponse = _reflection.GeneratedProtocolMessageType('PreviewPublicDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREVIEWPUBLICDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetResponse)
  })
_sym_db.RegisterMessage(PreviewPublicDatasetResponse)

ApplyPublicDatasetCRRequest = _reflection.GeneratedProtocolMessageType('ApplyPublicDatasetCRRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYPUBLICDATASETCRREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRRequest)
  })
_sym_db.RegisterMessage(ApplyPublicDatasetCRRequest)

ApplyPublicDatasetCRResponse = _reflection.GeneratedProtocolMessageType('ApplyPublicDatasetCRResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYPUBLICDATASETCRRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRResponse)
  })
_sym_db.RegisterMessage(ApplyPublicDatasetCRResponse)

ListPretrainedModelsRequest = _reflection.GeneratedProtocolMessageType('ListPretrainedModelsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPRETRAINEDMODELSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPRETRAINEDMODELSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest)
  })
_sym_db.RegisterMessage(ListPretrainedModelsRequest)
_sym_db.RegisterMessage(ListPretrainedModelsRequest.LabelsEntry)

ListPretrainedModelsResponse = _reflection.GeneratedProtocolMessageType('ListPretrainedModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPRETRAINEDMODELSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsResponse)
  })
_sym_db.RegisterMessage(ListPretrainedModelsResponse)

GetPretrainedModelRequest = _reflection.GeneratedProtocolMessageType('GetPretrainedModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPRETRAINEDMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetPretrainedModelRequest)
  })
_sym_db.RegisterMessage(GetPretrainedModelRequest)

GetPretrainedModelResponse = _reflection.GeneratedProtocolMessageType('GetPretrainedModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPRETRAINEDMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetPretrainedModelResponse)
  })
_sym_db.RegisterMessage(GetPretrainedModelResponse)

ListWorkloadClassesRequest = _reflection.GeneratedProtocolMessageType('ListWorkloadClassesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTWORKLOADCLASSESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTWORKLOADCLASSESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest)
  })
_sym_db.RegisterMessage(ListWorkloadClassesRequest)
_sym_db.RegisterMessage(ListWorkloadClassesRequest.LabelsEntry)

ListWorkloadClassesResponse = _reflection.GeneratedProtocolMessageType('ListWorkloadClassesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKLOADCLASSESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesResponse)
  })
_sym_db.RegisterMessage(ListWorkloadClassesResponse)

GetWorkloadClassRequest = _reflection.GeneratedProtocolMessageType('GetWorkloadClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKLOADCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassRequest)
  })
_sym_db.RegisterMessage(GetWorkloadClassRequest)

GetWorkloadClassResponse = _reflection.GeneratedProtocolMessageType('GetWorkloadClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKLOADCLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassResponse)
  })
_sym_db.RegisterMessage(GetWorkloadClassResponse)

ListUserRoleClassesRequest = _reflection.GeneratedProtocolMessageType('ListUserRoleClassesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTUSERROLECLASSESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTUSERROLECLASSESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesRequest)
  })
_sym_db.RegisterMessage(ListUserRoleClassesRequest)
_sym_db.RegisterMessage(ListUserRoleClassesRequest.LabelsEntry)

ListUserRoleClassesResponse = _reflection.GeneratedProtocolMessageType('ListUserRoleClassesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTUSERROLECLASSESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListUserRoleClassesResponse)
  })
_sym_db.RegisterMessage(ListUserRoleClassesResponse)

GetUserRoleClassRequest = _reflection.GeneratedProtocolMessageType('GetUserRoleClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERROLECLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetUserRoleClassRequest)
  })
_sym_db.RegisterMessage(GetUserRoleClassRequest)

GetUserRoleClassResponse = _reflection.GeneratedProtocolMessageType('GetUserRoleClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERROLECLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetUserRoleClassResponse)
  })
_sym_db.RegisterMessage(GetUserRoleClassResponse)


DESCRIPTOR._options = None
_LISTALGORITHMSREQUEST_LABELSENTRY._options = None
_LISTMLFRAMEWORKSREQUEST_LABELSENTRY._options = None
_LISTCLOUDSREQUEST_LABELSENTRY._options = None
_LISTPUBLICDATASETSREQUEST_LABELSENTRY._options = None
_LISTPRETRAINEDMODELSREQUEST_LABELSENTRY._options = None
_LISTWORKLOADCLASSESREQUEST_LABELSENTRY._options = None
_LISTUSERROLECLASSESREQUEST_LABELSENTRY._options = None

_CATALOGSERVICE = _descriptor.ServiceDescriptor(
  name='CatalogService',
  full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3968,
  serialized_end=7070,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListAlgorithm',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.ListAlgorithm',
    index=0,
    containing_service=None,
    input_type=_LISTALGORITHMSREQUEST,
    output_type=_LISTALGORITHMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\017\022\rv1/algorithms',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetAlgorithm',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.GetAlgorithm',
    index=1,
    containing_service=None,
    input_type=_GETALGORITHMREQUEST,
    output_type=_GETALGORITHMRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1/algorithms/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMLFrameworks',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.ListMLFrameworks',
    index=2,
    containing_service=None,
    input_type=_LISTMLFRAMEWORKSREQUEST,
    output_type=_LISTMLFRAMEWORKSRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/v1/mlframeworks',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMLFramework',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.GetMLFramework',
    index=3,
    containing_service=None,
    input_type=_GETMLFRAMEWORKREQUEST,
    output_type=_GETMLFRAMEWORKRESPONSE,
    serialized_options=b'\202\323\344\223\002\031\022\027/v1/mlframeworks/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListClouds',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.ListClouds',
    index=4,
    containing_service=None,
    input_type=_LISTCLOUDSREQUEST,
    output_type=_LISTCLOUDSRESPONSE,
    serialized_options=b'\202\323\344\223\002\014\022\n/v1/clouds',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetCloud',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.GetCloud',
    index=5,
    containing_service=None,
    input_type=_GETCLOUDREQUEST,
    output_type=_GETCLOUDRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\022\021/v1/clouds/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListWorkloadClasses',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.ListWorkloadClasses',
    index=6,
    containing_service=None,
    input_type=_LISTWORKLOADCLASSESREQUEST,
    output_type=_LISTWORKLOADCLASSESRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/v1/workloadclasses',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetWorkloadClass',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.GetWorkloadClass',
    index=7,
    containing_service=None,
    input_type=_GETWORKLOADCLASSREQUEST,
    output_type=_GETWORKLOADCLASSRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/v1/workloadclasses/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListUserRoleClasses',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.ListUserRoleClasses',
    index=8,
    containing_service=None,
    input_type=_LISTUSERROLECLASSESREQUEST,
    output_type=_LISTUSERROLECLASSESRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/v1/userroleclasses',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUserRoleClass',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.GetUserRoleClass',
    index=9,
    containing_service=None,
    input_type=_GETUSERROLECLASSREQUEST,
    output_type=_GETUSERROLECLASSRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/v1/userroleclasses/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListPublicDataset',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.ListPublicDataset',
    index=10,
    containing_service=None,
    input_type=_LISTPUBLICDATASETSREQUEST,
    output_type=_LISTPUBLICDATASETSRESPONSE,
    serialized_options=b'\202\323\344\223\002\024\022\022/v1/publicdatasets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPublicDataset',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.GetPublicDataset',
    index=11,
    containing_service=None,
    input_type=_GETPUBLICDATASETREQUEST,
    output_type=_GETPUBLICDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/v1/publicdatasets/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadPublicDataset',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.DownloadPublicDataset',
    index=12,
    containing_service=None,
    input_type=_DOWNLOADPUBLICDATASETREQUEST,
    output_type=_DOWNLOADPUBLICDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\002$\022\"/v1/publicdatasets/{name}:download',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PreviewPublicDataset',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.PreviewPublicDataset',
    index=13,
    containing_service=None,
    input_type=_PREVIEWPUBLICDATASETREQUEST,
    output_type=_PREVIEWPUBLICDATASETRESPONSE,
    serialized_options=b'\202\323\344\223\002#\022!/v1/publicdatasets/{name}:preview',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ApplyPublicDatasetCR',
    full_name='github.com.metaprov.modelaapi.services.catalog.v1.CatalogService.ApplyPublicDatasetCR',
    index=14,
    containing_service=None,
    input_type=_APPLYPUBLICDATASETCRREQUEST,
    output_type=_APPLYPUBLICDATASETCRRESPONSE,
    serialized_options=b'\202\323\344\223\002!\022\037/v1/publicdatasets/{name}:apply',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CATALOGSERVICE)

DESCRIPTOR.services_by_name['CatalogService'] = _CATALOGSERVICE

# @@protoc_insertion_point(module_scope)
